@@ -1,8 +1,9 @@
 #'@importFrom utils read.csv write.csv write.table View
+#'@import httr
 #'@docType package
 NULL
 
-CBSOPENDATA = "http://opendata.cbs.nl"
+CBSOPENDATA = "https://opendata.cbs.nl"
 API = "ODataApi/odata"
 BULK = "ODataFeed/odata"
 
