@@ -1,6 +1,6 @@
 #' @importFrom jsonlite fromJSON
 #' @importFrom utils URLencode
-resolve_resource <- function(url, ..., cache=TRUE){
+resolve_resource <- function(url, ..., verbose = TRUE, cache=TRUE){
   url <- utils::URLencode(url)
   
   if (isTRUE(cache)){
@@ -10,12 +10,12 @@ resolve_resource <- function(url, ..., cache=TRUE){
     }
   }
   
-  message(...," ", url)
+  if (verbose) { message(...," ", url) }
   # od <- httr::GET(url, httr::accept_json())
   # httr::stop_for_status(od, task = httr::http_status(od)$message)
   # res <- httr::content(od, "text", encoding="UTF-8")
   # res <- jsonlite::fromJSON(res)$value
-  res <- get_json(url)$value
+  res <- get_json(url, verbose = verbose)$value
   
   if (isTRUE(cache)){
     cache_add(url, res)
@@ -24,8 +24,10 @@ resolve_resource <- function(url, ..., cache=TRUE){
 }
 
 
-get_json <- function(url){
-  print(url)
+get_json <- function(url, verbose = TRUE){
+  if (verbose){
+    print(url)
+  }
   od <- httr::GET(url, httr::accept_json())
   httr::stop_for_status(od, task = httr::http_status(od)$message)
   res <- httr::content(od, "text", encoding="UTF-8")
